package com.readboy.provider;

import java.io.File;




import java.io.IOException;

import org.json.JSONException;
import org.json.JSONObject;

import com.readboy.encrypt.EncryptReader;
import com.readboy.provider.mhc.info.UserBaseInfo;
import com.readboy.provider.mhc.info.BookClassInfo;
import com.readboy.provider.mhc.info.DbConstants;
import com.readboy.provider.zsc.info.OldDbConstants;

import android.content.ContentUris;
import android.content.ContentValues;
import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.content.pm.PackageManager.NameNotFoundException;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.util.Log;

public class UserDbSearch {

	final String TAG = "----UserInfoDb----";
	private static final int NEW_PERSONALINFO_VERSION = 300;
	private static UserDbSearch userInfoDb = null;
	private Context mContext;
	public static UserDbSearch getInstance(Context context)
	{
		if(userInfoDb == null)
		{
			userInfoDb = new UserDbSearch(context);
		}
		return userInfoDb;
	}
	
	private UserDbSearch(Context context)
	{
		this.mContext = context;
	}
	
	
	
	
	
	/**获取用户头像*/
	public Bitmap getUserIcon()
	{
		if(NEW_PERSONALINFO_VERSION > getPersonalInfoVersionCode())
		{
			Bitmap bmp = null;
			if((new File(OldDbConstants.ICONPATH + OldDbConstants.IMGTYPE)).exists()){
				bmp = BitmapFactory.decodeFile(OldDbConstants.ICONPATH + OldDbConstants.IMGTYPE);
			}
			return bmp;
		}
		return getUserIconFromDb();
	}
	
	
	public UserBaseInfo getUserInfo()
	{
		if(NEW_PERSONALINFO_VERSION > getPersonalInfoVersionCode())
		{
			return getUserInfoFromFile();
		}
		return getUserInfoFromDatabase();
	}
	
	
	
	
	
	/**
	 * 老版个人中心获取token
	 * @return
	 */
	public String getToken(){
		
		//boolean needLog,boolean display
//		if(needLog && display){
//			Intent intent = new Intent();
//			ComponentName cn = new ComponentName(PKGNAME, ACTNAME);
//			intent.setComponent(cn);
////			intent.setAction(Intent.ACTION_MAIN);
////			intent.addCategory(Intent.CATEGORY_LAUNCHER);
////			intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_RESET_TASK_IF_NEEDED);
//			//intent.setFlags(Intent.FLAG_ACTIVITY_RESET_TASK_IF_NEEDED);
//			((Activity)mContext).startActivityForResult(intent, requestCode);
//			
//			return "";
//		}
//		
//		
//		if(!isPersonalFileExit()){
//			return "";
//		}
		String tokenName = OldDbConstants.T_TOKEN;
		try{
			Uri uri = Uri.parse("content://" +  "com.readboy.personal.personalProvider"+"/PersonalProvider");
			Cursor cursor = mContext.getContentResolver().
					query(uri, new String[]{tokenName}, "_id=?", new String[]{"1"}, null);
			
			if(cursor == null){
				//this.close();
				return null;
			}
			
			cursor.moveToFirst();
			int index = cursor.getColumnIndexOrThrow(tokenName);
			String token =  cursor.getString(index);
			cursor.close();
			return token;
		}catch(Exception e){
			return "";
		}
		
	}
	
	
	
	
	
	
	/**
	 * 更新数据库里面的class   token
	 */
	public static void writeClassToken(Context mContext, String classToken){
		ContentValues values = new ContentValues();
		if(classToken == null)
		{
			classToken = "";
		}
		values.put(DbConstants.T_CLASS_TOKEN,classToken);
		mContext.getContentResolver().insert(DbConstants.USER_INFO_CONTENT_URI, values);
	}
	
	
	/**
	 * 更新数据库里面的class   token
	 */
	public static String getClassToken(Context mContext){
		Uri userInfoUri = Uri.parse("content://" + DbConstants.AUTHORITY + 
				"/"+DbConstants.USERINFO_TABLE);
		Cursor userInfoCursor = mContext.getContentResolver().query(userInfoUri, null, null, null, null);
		
		if(userInfoCursor == null || !userInfoCursor.moveToFirst()){
			if(userInfoCursor != null)
			{
				userInfoCursor.close();
			}
			return "";
		}
		
		int classTokenIndex = userInfoCursor.getColumnIndex(DbConstants.T_CLASS_TOKEN);
		String classToken = userInfoCursor.getString(classTokenIndex);
		userInfoCursor.close();
		return classToken;
	}
	
	
	
	/**
	 * 获取头像
	 */
	private Bitmap getUserIconFromDb(){
		
		
		//新版个人中心，其他应用获取头像的方法（读取数据库）
		
		Uri uri = Uri.parse("content://" + DbConstants.AUTHORITY + 
				"/"+DbConstants.USERINFO_TABLE);
		Cursor cursor = null;
		try
		{
			cursor = mContext.getContentResolver().query(
					uri, new String[]{DbConstants.T_BLOB}, "_id=?", new String[]{"1"}, null);
		}
		catch(Throwable e)
		{
			return null;
		}
		if(cursor == null || !cursor.moveToFirst()){
			if(cursor != null)
			{
				cursor.close();
			}
			return null;
		}
		int index = cursor.getColumnIndexOrThrow(DbConstants.T_BLOB);
		byte[] iconByte =  cursor.getBlob(index);
		cursor.close();
		
		if(iconByte == null)
		{
			return null;
		}
		/*根据bitmap字节数据转换成Bitmap对象*/
		Bitmap bm = BitmapFactory.decodeByteArray(iconByte, 0, iconByte.length);
		
		return bm;
	}
	
	
	private UserBaseInfo getUserInfoFromDatabase()
	{
		LogD(TAG, "mhc----------getUserInfoFromDatabase()");
		Uri userInfoUri = Uri.parse("content://" + DbConstants.AUTHORITY + 
				"/"+DbConstants.USERINFO_TABLE);
		Cursor userInfoCursor = null;
		try
		{
			userInfoCursor = mContext.getContentResolver().query(userInfoUri, null, null, null, null);
		}
		catch(Throwable e)
		{
			return null;
		}
		
		if(userInfoCursor == null || !userInfoCursor.moveToFirst()){
			if(userInfoCursor != null)
			{
				userInfoCursor.close();
			}
			return null;
		}
		
		UserBaseInfo mUserInfo = new UserBaseInfo();
		
		int uidIndex = userInfoCursor.getColumnIndex(DbConstants.T_UID);
		int userNameIndex = userInfoCursor.getColumnIndex(DbConstants.T_USERNAME);
		int realNameIndex = userInfoCursor.getColumnIndex(DbConstants.T_REALNAME);
		int passwordIndex = userInfoCursor.getColumnIndex(DbConstants.T_PW);
		int tokenIndex = userInfoCursor.getColumnIndex(DbConstants.T_TOKEN);
		int classTokenIndex = userInfoCursor.getColumnIndex(DbConstants.T_CLASS_TOKEN);
		int photoUriIndex = userInfoCursor.getColumnIndex(DbConstants.T_PHOTO_URI);
		
		int genderIndex = userInfoCursor.getColumnIndex(DbConstants.T_GENDER);
		int genderStrIndex = userInfoCursor.getColumnIndex(DbConstants.T_GENDERSTR);
		int birthYearIndex = userInfoCursor.getColumnIndex(DbConstants.T_BIRTH_YEAR);
		int birthMonthIndex = userInfoCursor.getColumnIndex(DbConstants.T_BIRTH_MONTH);
		int birthDayIndex = userInfoCursor.getColumnIndex(DbConstants.T_BIRTH_DAY);
		int moneyIndex = userInfoCursor.getColumnIndex(DbConstants.T_MONEY);
		int beanIndex = userInfoCursor.getColumnIndex(DbConstants.T_BEAN);
		int mobileIndex = userInfoCursor.getColumnIndex(DbConstants.T_MOBILE);
		
		mUserInfo.uid = userInfoCursor.getInt(uidIndex);
		mUserInfo.userName = userInfoCursor.getString(userNameIndex);
		mUserInfo.realName = userInfoCursor.getString(realNameIndex);
		mUserInfo.passWord = userInfoCursor.getString(passwordIndex);
		mUserInfo.token = userInfoCursor.getString(tokenIndex);
		mUserInfo.class_token = userInfoCursor.getString(classTokenIndex);
		
		mUserInfo.photoUri = userInfoCursor.getString(photoUriIndex);
		
		//新版加入的个人信息：性别，生日
		mUserInfo.gender = userInfoCursor.getInt(genderIndex);
		mUserInfo.genderStr = userInfoCursor.getString(genderStrIndex);
		mUserInfo.birthYear = userInfoCursor.getInt(birthYearIndex);
		mUserInfo.birthMonth = userInfoCursor.getInt(birthMonthIndex);
		mUserInfo.birthDay = userInfoCursor.getInt(birthDayIndex);
		mUserInfo.money = userInfoCursor.getInt(moneyIndex);
		mUserInfo.bean = userInfoCursor.getInt(beanIndex);
		mUserInfo.mobile = userInfoCursor.getString(mobileIndex);
		
		//int bmpIndex = cursor.getColumnIndex(T_BLOB);
		/**
		 * 得到bitmap字节数据
		 */
		//mUserInfo.bmpByteArray = cursor.getBlob(bmpIndex);
		
		userInfoCursor.close();
		
		
		
		
		return getUserBooksFromDatabase(mUserInfo);
	}
	

	
	
	private UserBaseInfo getUserBooksFromDatabase(UserBaseInfo mUserInfo)
	{
		LogD(TAG, "mhc----------getUserBooksFromDatabase()");
		Uri userInfoUri = Uri.parse("content://" + DbConstants.AUTHORITY + 
				"/"+DbConstants.USER_BOOKS_TABLE);
		Cursor userBooksCursor = mContext.getContentResolver().query(userInfoUri, null, null, null, null);
		
		if(userBooksCursor == null || !userBooksCursor.moveToFirst()){
			if(userBooksCursor != null)
			{
				userBooksCursor.close();
			}
			
			return mUserInfo;
		}
		int stageIndex = userBooksCursor.getColumnIndex(DbConstants.S_STAGE);
		int gradeIndex = userBooksCursor.getColumnIndex(DbConstants.S_GRADE);
		int gradeStrIndex = userBooksCursor.getColumnIndex(DbConstants.S_GRADESTR);
		int schoolIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_SCHOOLID);
		int schoolNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_SCHOOLNAME);
		
		int provIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_PROVINCEID);
		int cityIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_CITYID);
		int districtIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_DISTRICTID);
		int provStrIndex = userBooksCursor.getColumnIndex(DbConstants.S_PROVINCESTR);
		int cityStrIndex = userBooksCursor.getColumnIndex(DbConstants.S_CITYSTR);
		int districtStrIndex = userBooksCursor.getColumnIndex(DbConstants.S_DISTRICTSTR);
		
		
//		int yuwenIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_YW_ID);
//		int shuxueIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_SX_ID);
//		int yingyuIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_YY_ID);
//		int wuliIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_WL_ID);
//		int huaxueIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_HX_ID);
//		int shengwuIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_SW_ID);
//		int lishiIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_LS_ID);
//		int diliIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_DL_ID);
//		int zhengzhiIdIndex = userBooksCursor.getColumnIndex(DbConstants.S_ZZ_ID);
//		
//		int yuwenNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_YW_NAME);
//		int shuxueNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_SX_NAME);
//		int yingyuNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_YY_NAME);
//		int wuliNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_WL_NAME);
//		int huaxueNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_HX_NAME);
//		int shengwuNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_SW_NAME);
//		int lishiNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_LS_NAME);
//		int diliNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_DL_NAME);
//		int zhengzhiNameIndex = userBooksCursor.getColumnIndex(DbConstants.S_ZZ_NAME);
		
		mUserInfo.stage = userBooksCursor.getInt(stageIndex);
		mUserInfo.gradeInt = userBooksCursor.getInt(gradeIndex);
		mUserInfo.gradeStr = userBooksCursor.getString(gradeStrIndex);
		mUserInfo.schoolId = userBooksCursor.getInt(schoolIdIndex);
		mUserInfo.schoolName = userBooksCursor.getString(schoolNameIndex);
		
		mUserInfo.provId = userBooksCursor.getInt(provIdIndex);
		mUserInfo.cityId = userBooksCursor.getInt(cityIdIndex);
		mUserInfo.districtId = userBooksCursor.getInt(districtIdIndex);
		mUserInfo.provStr = userBooksCursor.getString(provStrIndex);
		mUserInfo.cityStr = userBooksCursor.getString(cityStrIndex);
		mUserInfo.districtStr = userBooksCursor.getString(districtStrIndex);
		
//		mUserInfo.yw = userBooksCursor.getInt(yuwenIdIndex);
//		mUserInfo.sx = userBooksCursor.getInt(shuxueIdIndex);
//		mUserInfo.yy = userBooksCursor.getInt(yingyuIdIndex);
//		mUserInfo.wl = userBooksCursor.getInt(wuliIdIndex);
//		mUserInfo.hx = userBooksCursor.getInt(huaxueIdIndex);
//		mUserInfo.sw = userBooksCursor.getInt(shengwuIdIndex);
//		mUserInfo.ls = userBooksCursor.getInt(lishiIdIndex);
//		mUserInfo.dl = userBooksCursor.getInt(diliIdIndex);
//		mUserInfo.zz = userBooksCursor.getInt(zhengzhiIdIndex);
//		mUserInfo.ywName = userBooksCursor.getString(yuwenNameIndex);
//		mUserInfo.sxName = userBooksCursor.getString(shuxueNameIndex);
//		mUserInfo.yyName = userBooksCursor.getString(yingyuNameIndex);
//		mUserInfo.wlName = userBooksCursor.getString(wuliNameIndex);
//		mUserInfo.hxName = userBooksCursor.getString(huaxueNameIndex);
//		mUserInfo.swName = userBooksCursor.getString(shengwuNameIndex);
//		mUserInfo.lsName = userBooksCursor.getString(lishiNameIndex);
//		mUserInfo.dlName = userBooksCursor.getString(diliNameIndex);
//		mUserInfo.zzName = userBooksCursor.getString(zhengzhiNameIndex);
		
		
		userBooksCursor.close();
		
		
		
		
		return mUserInfo;
	}
	
	
	
	
	
	/**
	 * 获取教材信息
	 * @param subjectId 范围1到9分别代表（语数外物化生政史地）
	 * @return
	 */
	public BookClassInfo getBookClassInfo(int subjectId)
	{
		if(subjectId < 1 || subjectId > 9)
		{
			return null;
		}
		Uri uri1 = Uri.parse("content://" + DbConstants.AUTHORITY + 
				"/"+DbConstants.BOOK_CLASS_TABLE);
		Uri uri = ContentUris.withAppendedId(uri1, subjectId);
		Cursor cursor = mContext.getContentResolver().query(uri, null, null, null, null);
		
		if(cursor == null || !cursor.moveToFirst()){
			if(cursor != null)
			{
				cursor.close();
			}
			return null;
		}
		
		
		BookClassInfo bookInfo = new BookClassInfo();
		
		int idIndex = cursor.getColumnIndex(DbConstants.B_ID);
		int bookIdIndex = cursor.getColumnIndex(DbConstants.B_BOOK_ID);
		int bookNameIndex = cursor.getColumnIndex(DbConstants.B_BOOK_NAME);
		int gradeIdIndex = cursor.getColumnIndex(DbConstants.B_BOOK_GRADE_ID);
		int subjectIdIndex = cursor.getColumnIndex(DbConstants.B_BOOK_SUB_ID);
		int editionIdIndex = cursor.getColumnIndex(DbConstants.B_EDITION_ID);
		int editionNameIndex = cursor.getColumnIndex(DbConstants.B_EDITION_NAME);
		int pubIdIndex = cursor.getColumnIndex(DbConstants.B_PUBID);
		int pubNameIndex = cursor.getColumnIndex(DbConstants.B_PUBNAME);
		int subjectVisibleIndex = cursor.getColumnIndex(DbConstants.B_SUBJECT_VISIBLE);
		int coverPathIndex = cursor.getColumnIndex(DbConstants.B_COVER_PATH);
		int classIdIndex = cursor.getColumnIndex(DbConstants.B_CLASSID);
		int classNameIndex = cursor.getColumnIndex(DbConstants.B_CLASSNAME);
		
		bookInfo.subjectId = cursor.getInt(idIndex);//subjectId
		bookInfo.bookId = cursor.getInt(bookIdIndex);
		bookInfo.bookName = cursor.getString(bookNameIndex);
		bookInfo.gradeId = cursor.getInt(gradeIdIndex);
		bookInfo.subjectId = cursor.getInt(subjectIdIndex);
		bookInfo.editionId = cursor.getInt(editionIdIndex);
		bookInfo.editionName = cursor.getString(editionNameIndex);
		bookInfo.pressId = cursor.getInt(pubIdIndex);
		bookInfo.pressName = cursor.getString(pubNameIndex);
		bookInfo.subjectVisible = cursor.getInt(subjectVisibleIndex);
		bookInfo.coverPath = cursor.getString(coverPathIndex);
		bookInfo.classId = cursor.getString(classIdIndex);
		bookInfo.className = cursor.getString(classNameIndex);
		
		cursor.close();
		return bookInfo;
	}
	
	
	/**
	 * 获取教材封面（注意返回封面可能为null）
	 */
	public Bitmap getBookCoverFromDb(int subjectId){
		
		
		//新版个人中心，其他应用获取头像的方法（读取数据库）
		
		Uri uri = Uri.parse("content://" + DbConstants.AUTHORITY + 
				"/"+DbConstants.BOOK_CLASS_TABLE);
		Cursor cursor = mContext.getContentResolver().query(
				uri, new String[]{DbConstants.B_BLOB}, "_id=?", new String[]{""+subjectId}, null);
		
		if(cursor == null || !cursor.moveToFirst()){
			if(cursor != null)
			{
				cursor.close();
			}
			return null;
		}
		int index = cursor.getColumnIndexOrThrow(DbConstants.B_BLOB);
		byte[] iconByte =  cursor.getBlob(index);
		cursor.close();
		
		if(iconByte == null)
		{
			return null;
		}
		/*根据bitmap字节数据转换成Bitmap对象*/
		Bitmap bm = BitmapFactory.decodeByteArray(iconByte, 0, iconByte.length);
		
		return bm;
	}
	
	
	
	
	
	
	
	
	
	
	
	private boolean isPersonalFileExit(){
		boolean exit = true;
		
		File file1 = new File(OldDbConstants.USERINFOPATH);
		File file2 = new File(OldDbConstants.SUBJECTPATH);
		File file3 = new File(OldDbConstants.USERINFOPATH+".txt");
		LogD(TAG, "mhc-------file1 exists = "+file1.exists());
		LogD(TAG, "mhc-------file1 exists = "+file2.exists());
		LogD(TAG, "mhc-------file3 exists = "+file3.exists());
		if(!file1.exists() || !file2.exists() || !file3.exists()){
			exit = false;
		}
		
		return exit;
	}
	
	private int getPersonalInfoVersionCode()
	{
		// 获取packagemanager的实例
        PackageManager packageManager = mContext.getPackageManager();
        // getPackageName()是你当前类的包名，0代表是获取版本信息
        PackageInfo packInfo;
        int versionCode = 1;
		try {
			packInfo = packageManager.getPackageInfo(DbConstants.PKGNAME,0);
			versionCode = packInfo.versionCode;
		} catch (NameNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		LogD(TAG, "个人中心的版本是"+versionCode);
        return versionCode;
	}
	
	
	
	private UserBaseInfo getUserInfoFromFile()
	{
		LogD(TAG, "mhc----------getUserInfoFromFile()");
		if(!isPersonalFileExit()){
			LogD(TAG, "mhc----------!isPersonalFileExit()");
			return null;
		}
		else
		{
			String infoStr = readTxtInfo();
			
			String[] infoStrs = infoStr.split("\\n");
			JSONObject jb = new JSONObject();
			//jb.put
			
			for(int i = 0 ; i < infoStrs.length; i++){
				String[] elements = infoStrs[i].split("=");
				
				if(elements.length == 2 && elements[0] != null && 
						!elements[0].isEmpty() && elements[1] != null){
					try {
						jb.put(elements[0], elements[1]);
					} catch (JSONException e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
				}
				
			}
			LogD("zsc", "jb = " + jb.toString());
			UserBaseInfo mUserInfo = new UserBaseInfo();
			try {
				mUserInfo.uid = jb.getInt(DbConstants.T_UID);
				mUserInfo.userName = jb.getString(DbConstants.T_USERNAME);
				mUserInfo.realName = jb.getString(DbConstants.T_REALNAME);
				mUserInfo.gradeInt = jb.getInt(DbConstants.T_GRADE);
				if(mUserInfo.gradeInt < 513) //服务器那边的年级没填
					mUserInfo.gradeInt = 0;
		    	else
		    		mUserInfo.gradeInt = gradeDbIdToId(mUserInfo.gradeInt);
				mUserInfo.gradeStr = getGradeFromIntToStr(mUserInfo.gradeInt);
				
				
				mUserInfo.schoolName = jb.getString(DbConstants.T_SCHSTR);
				mUserInfo.schoolId = jb.getInt(DbConstants.T_SCHID);
				
				mUserInfo.provStr = jb.getString(DbConstants.T_PROVSTR);
				mUserInfo.cityStr = jb.getString(DbConstants.T_CITYSTR);
				mUserInfo.provId = jb.getInt(DbConstants.T_PROVINCEID);
				mUserInfo.cityId = jb.getInt(DbConstants.T_CITYID);
				
//				mUserInfo.chiId = jb.getInt(DbConstants.T_CHIID);
//				mUserInfo.mathId = jb.getInt(DbConstants.T_MATH);
//				mUserInfo.engId = jb.getInt(DbConstants.T_ENGLISH);
//				mUserInfo.phyId = jb.getInt(DbConstants.T_PHYSICS);
//				mUserInfo.chemId = jb.getInt(DbConstants.T_CHMI);
//				mUserInfo.hisId = jb.getInt(DbConstants.T_HIS);
//				mUserInfo.bioId = jb.getInt(DbConstants.T_BIO);
//				mUserInfo.polityId = jb.getInt(DbConstants.T_POLI);
//				mUserInfo.scienceId = jb.getInt(DbConstants.T_SCIEN);
				
			} catch (JSONException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			mUserInfo.token = getToken();
			return mUserInfo;
		}
	}
	
	private String[] gradeStr = {
			  "一年级"
			 ,"二年级"
			 ,"三年级"
			 ,"四年级"
			 ,"五年级"
			 ,"六年级"
			 ,"七年级"
			 ,"八年级"
			 ,"九年级"
			 ,"高一"
			 ,"高二"
			 ,"高三"};
	private String getGradeFromIntToStr(int grade)
	{
		return gradeStr[grade];
	}
	
	//统一的转为适配器的id
	public int gradeDbIdToId(int id)
	{
		int graInDbId;
    	if(id >= 769)
    		graInDbId = id - 760;
    	else
    		graInDbId = id - 513;
    	
    	return graInDbId;
	}

	
	private String readTxtInfo(){
		
		String s = "";
		
		try {
			//实例化一个解密类
			EncryptReader eis = new EncryptReader(OldDbConstants.USERINFOPATH + ".txt");
			//获取文件大小
			int av = eis.available();
			
			if(av > 0){
				//分配字节空间
				byte[] buff = new byte[av];
				
				//读取字节数据，并解密
				eis.read(buff);
				
				//加密是按gbk编码加密的，所以解密成gbk
				s = new String(buff, "gbk");
				//打印结果
				LogD("encryption", s);
				
			}
			//关闭文件
			eis.close();
			return s;
			
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		return null;
	}
		
	
	private boolean showDebugInfo = true;
	public void setShowDebugInfo(boolean showDebugInfo)
	{
		this.showDebugInfo = showDebugInfo;
	}
	
	private void LogD(String tag, String info)
	{
		if(showDebugInfo)
		{
			Log.d(tag, info);
		}
	}
}
